@@ -52,6 +52,14 @@ REPLACERS = [
     'RESPONSE',
 ]
 
+# The list of approved type casts and associated functions
+APPROVED_CASTS = {
+    'int': int,
+    'float': float,
+    'str': str,
+    'bool': bool
+}
+
 # Basic test template determining both valid keys and default values
 BASE_TEST = {
     'name': '',
@@ -70,6 +78,7 @@ BASE_TEST = {
     'skip': '',
     'poll': {},
     'use_prior_test': True,
+    'disable_response_handler': False
 }
 
 
@@ -125,6 +134,9 @@ class HTTPTestCase(unittest.TestCase):
         for fixture in self._fixture_cleanups:
             fixture.cleanUp()
 
+    def shortDescription(self):
+        return self.test_base_name + ': ' + self.test_data['name']
+
     def run(self, result=None):
         """Store the current result handler on this test."""
         self.result = result
@@ -136,11 +148,13 @@ class HTTPTestCase(unittest.TestCase):
 
         If there is a prior test in the sequence, run it first.
         """
+        self.cast = None
         if self.has_run:
             return
 
-        if self.test_data['skip']:
-            self.skipTest(self.test_data['skip'])
+        skip = self.replace_template(self.test_data['skip'])
+        if skip:
+            self.skipTest(skip)
 
         if (self.prior and not self.prior.has_run and
                 self.test_data['use_prior_test']):
@@ -216,6 +230,17 @@ class HTTPTestCase(unittest.TestCase):
         else:
             return replacer
 
+    def _cast_value(self, value, message):
+        """Cast a replacement value the cast is in APPROVED_CASTS."""
+        # Turn off the casting flag, to reset state
+        cast = self.cast
+        self.cast = None
+        if cast in APPROVED_CASTS:
+            return APPROVED_CASTS[cast](value)
+        else:
+            raise RuntimeError('Invalid cast <%s> used in: %s' % (
+                cast, message))
+
     def _environ_replace(self, message, escape_regex=False):
         """Replace an indicator in a message with the environment value.
 
@@ -226,29 +251,33 @@ class HTTPTestCase(unittest.TestCase):
                        self._regex_replacer(self._environ_replacer,
                                             escape_regex),
                        message)
-        try:
-            if '.' in value:
-                value = float(value)
-            else:
-                value = int(value)
+        if self.cast:
+            return self._cast_value(value, message)
+        else:
+            try:
+                if '.' in value:
+                    value = float(value)
+                else:
+                    value = int(value)
+                return value
+            except ValueError:
+                pass
+            if value.lower() == "false":
+                return False
+            if value.lower() == "true":
+                return True
+            if value.lower() == "null":
+                return None
             return value
-        except ValueError:
-            pass
-        if value.lower() == "false":
-            return False
-        if value.lower() == "true":
-            return True
-        if value.lower() == "null":
-            return None
-        return value
 
-    @staticmethod
-    def _environ_replacer(match):
+    def _environ_replacer(self, match):
         """Replace a regex match with an environment value.
 
-        Let KeyError raise if variable not present.
+        Let KeyError raise if variable not present. Capture
+        the 'cast' if any.
         """
         environ_name = match.group('arg')
+        self.cast = match.group('cast')
         return os.environ[environ_name]
 
     def _cookie_replace(self, message, escape_regex=False):
@@ -401,8 +430,10 @@ class HTTPTestCase(unittest.TestCase):
     def _replacer_regex(key):
         """Compose a regular expression for test template variables."""
         case = HTTPTestCase._history_regex
-        return r"%s\$%s\[(?P<quote>['\"])(?P<arg>.+?)(?P=quote)\]" % (
-            case, key)
+        return (
+            r"%s\$%s(:(?P<cast>\w+))?"
+            r"\[(?P<quote>['\"])(?P<arg>.+?)(?P=quote)\]"
+            % (case, key))
 
     @staticmethod
     def _simple_replacer_regex(key):
@@ -429,6 +460,11 @@ class HTTPTestCase(unittest.TestCase):
         """Replace a regex match with the value from a previous response."""
         response_path = match.group('arg')
         case = match.group('case')
+        self.cast = match.group('cast')
+        if not preserve and self.cast:
+            raise RuntimeError(
+                'Unable to process cast <%s> within message: %s'
+                % (self.cast, match.string))
         if case:
             referred_case = self.history[case]
         else:
@@ -441,6 +477,8 @@ class HTTPTestCase(unittest.TestCase):
         result = replacer_class.replacer(
             referred_case.response_data, response_path)
         if preserve:
+            if self.cast:
+                return self._cast_value(result, match.string)
             return result
         else:
             return six.text_type(result)
@@ -478,9 +516,15 @@ class HTTPTestCase(unittest.TestCase):
         decoded_output = utils.decode_response_content(response, content)
         self.content_type = response.get('content-type', '').lower()
         loader_class = self.get_content_handler(self.content_type)
-        if decoded_output and loader_class:
+        if (decoded_output and loader_class
+                and not self.test_data['disable_response_handler']):
             # save structured response data
-            self.response_data = loader_class.loads(decoded_output)
+            try:
+                self.response_data = loader_class.loads(decoded_output)
+            except exception.GabbiDataLoadError as exc:
+                raise AssertionError(
+                    'unable to load data as %s' % self.content_type) from exc
+
         else:
             self.response_data = None
         self.output = decoded_output
@@ -584,8 +628,12 @@ class HTTPTestCase(unittest.TestCase):
                 data = self.replace_template(data)
                 data = dumper_class.dumps(data, test=self)
             else:
-                raise ValueError(
-                    'unable to process data to %s' % content_type)
+                if content_type:
+                    raise ValueError(
+                        'unable to process data to %s' % content_type)
+                else:
+                    raise ValueError(
+                        'no content-type available for processing data')
 
         data = self.replace_template(data)
 
