@@ -41,7 +41,7 @@ from gabbi import utils
 def build_tests(path, loader, host=None, port=8001, intercept=None,
                 test_loader_name=None, fixture_module=None,
                 response_handlers=None, content_handlers=None,
-                prefix='', require_ssl=False, url=None,
+                prefix='', require_ssl=False, cert_validate=True, url=None,
                 inner_fixtures=None, verbose=False,
                 use_prior_test=True, safe_yaml=True):
     """Read YAML files from a directory to create tests.
@@ -65,13 +65,17 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
     :param require_ssl: If ``True``, make all tests default to using SSL.
     :param inner_fixtures: A list of ``Fixtures`` to use with each
                            individual test request.
+    :type inner_fixtures: List of classes with setUp and cleanUp methods to
+                          be used as fixtures.
     :param verbose: If ``True`` or ``'all'``, make tests verbose by default
                     ``'headers'`` and ``'body'`` are also accepted.
     :param use_prior_test: If ``True``, uses prior test to create ordered
                            sequence of tests
     :param safe_yaml: If ``True``, recognizes only standard YAML tags and not
                       Python object
-    :type inner_fixtures: List of fixtures.Fixture classes.
+    :param cert_validate: If ``False`` ssl server certificate will be ignored,
+                        further it will not be validated if provided
+                        (set cert_reqs=CERT_NONE to the Http object)
     :rtype: TestSuite containing multiple TestSuites (one for each YAML file).
     """
 
@@ -83,7 +87,7 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
 
     # Exit immediately if we have no host to access, either via a real host
     # or an intercept.
-    if not bool(host) ^ bool(intercept):
+    if not ((host is not None) ^ bool(intercept)):
         raise AssertionError(
             'must specify exactly one of host or url, or intercept')
 
@@ -132,6 +136,12 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
             else:
                 suite_dict['defaults'] = {'verbose': verbose}
 
+        if not cert_validate:
+            if 'defaults' in suite_dict:
+                suite_dict['defaults']['cert_validate'] = False
+            else:
+                suite_dict['defaults'] = {'cert_validate': False}
+
         if not use_prior_test:
             if 'defaults' in suite_dict:
                 suite_dict['defaults']['use_prior_test'] = use_prior_test
@@ -152,15 +162,19 @@ def py_test_generator(test_dir, host=None, port=8001, intercept=None,
                       fixture_module=None, response_handlers=None,
                       content_handlers=None, require_ssl=False, url=None,
                       metafunc=None, use_prior_test=True,
-                      inner_fixtures=None, safe_yaml=True):
+                      inner_fixtures=None, safe_yaml=True, cert_validate=True):
     """Generate tests cases for py.test
 
     This uses build_tests to create TestCases and then yields them in
     a way that pytest can handle.
     """
 
-    import pytest
-    pluginmanager = pytest.config.pluginmanager
+    if metafunc:
+        pluginmanager = metafunc.config.pluginmanager
+    else:
+        import pytest
+        pluginmanager = pytest.config.pluginmanager
+
     pluginmanager.import_plugin('gabbi.pytester')
 
     loader = unittest.TestLoader()
@@ -173,7 +187,7 @@ def py_test_generator(test_dir, host=None, port=8001, intercept=None,
                         content_handlers=content_handlers,
                         prefix=prefix, require_ssl=require_ssl,
                         url=url, use_prior_test=use_prior_test,
-                        safe_yaml=safe_yaml)
+                        safe_yaml=safe_yaml, cert_validate=cert_validate)
 
     test_list = []
     for test in tests:
