@@ -409,4 +409,4 @@ class HTMLResponseHandler(base.ResponseHandler):
     def action(self, test, item, value=None):
         doc = test.output
         html = '<{tag}>{content}</{tag}>'.format(tag=item, content=value)
-        test.assertTrue(html in doc, "no elements matching '%s'" % html)
+        test.assertIn(html, doc, "no elements matching '%s'" % html)
